==> ejc-businessplan-impl-3.0.0-20220703.150729-92-sources.jar: com/ejianc/business/busniessplan/bean/FundsplanningdetailEntity.java <==
package com.ejianc.business.busniessplan.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目资金管理策划子表
 *
 * @author generator
 *
 */
 @TableName("ejc_businessplan_fundsplanningdetail")
public class FundsplanningdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="collectbranch_time")
    private java.util.Date collectbranchTime; // 收支时间(日期)
    @TableField(value="collectbranch_time1")
    private java.lang.String collectbranchTime1; // 收支时间(文本)
    @TableField(value="imagenode")
    private java.lang.String imagenode; // 形象进度节点情况
    @TableField(value="plancomplete")
    private java.math.BigDecimal plancomplete; // 计划完成产值
    @TableField(value="civilengineering")
    private java.math.BigDecimal civilengineering; // 土建
    @TableField(value="installation")
    private java.math.BigDecimal installation; // 安装
    @TableField(value="other")
    private java.math.BigDecimal other; // 其它
    @TableField(value="labourservices")
    private java.math.BigDecimal labourservices; // 劳务
    @TableField(value="material")
    private java.math.BigDecimal material; // 材料
    @TableField(value="professional")
    private java.math.BigDecimal professional; // 专业分包
    @TableField(value="othercost")
    private java.math.BigDecimal othercost; // 其它费用
    @TableField(value="current")
    private java.math.BigDecimal current; // 当期
    @TableField(value="cumulative")
    private java.math.BigDecimal cumulative; // 累计
    @TableField(value="answer")
    private java.math.BigDecimal answer; // 应对措施
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="salary")
    private java.math.BigDecimal salary; // 工资
    @TableField(value="cio_amount")
    private java.lang.String cioAmount;//合计

    public String getCioAmount() {
        return cioAmount;
    }

    public void setCioAmount(String cioAmount) {
        this.cioAmount = cioAmount;
    }





    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 收支时间(日期)
     */
    public java.util.Date getCollectbranchTime() {
        return collectbranchTime;
    }

    /**
     * 收支时间(日期)
     */
    public void setCollectbranchTime(java.util.Date collectbranchTime) {
        this.collectbranchTime = collectbranchTime;
    }
    /**
     * 形象进度节点情况
     */
    public java.lang.String getImagenode() {
        return imagenode;
    }

    /**
     * 形象进度节点情况
     */
    public void setImagenode(java.lang.String imagenode) {
        this.imagenode = imagenode;
    }
    /**
     * 计划完成产值
     */
    public java.math.BigDecimal getPlancomplete() {
        return plancomplete;
    }

    /**
     * 计划完成产值
     */
    public void setPlancomplete(java.math.BigDecimal plancomplete) {
        this.plancomplete = plancomplete;
    }
    /**
     * 土建
     */
    public java.math.BigDecimal getCivilengineering() {
        return civilengineering;
    }

    /**
     * 土建
     */
    public void setCivilengineering(java.math.BigDecimal civilengineering) {
        this.civilengineering = civilengineering;
    }
    /**
     * 安装
     */
    public java.math.BigDecimal getInstallation() {
        return installation;
    }

    /**
     * 安装
     */
    public void setInstallation(java.math.BigDecimal installation) {
        this.installation = installation;
    }
    /**
     * 其它
     */
    public java.math.BigDecimal getOther() {
        return other;
    }

    /**
     * 其它
     */
    public void setOther(java.math.BigDecimal other) {
        this.other = other;
    }
    /**
     * 劳务
     */
    public java.math.BigDecimal getLabourservices() {
        return labourservices;
    }

    /**
     * 劳务
     */
    public void setLabourservices(java.math.BigDecimal labourservices) {
        this.labourservices = labourservices;
    }
    /**
     * 材料
     */
    public java.math.BigDecimal getMaterial() {
        return material;
    }

    /**
     * 材料
     */
    public void setMaterial(java.math.BigDecimal material) {
        this.material = material;
    }
    /**
     * 专业分包
     */
    public java.math.BigDecimal getProfessional() {
        return professional;
    }

    /**
     * 专业分包
     */
    public void setProfessional(java.math.BigDecimal professional) {
        this.professional = professional;
    }
    /**
     * 其它费用
     */
    public java.math.BigDecimal getOthercost() {
        return othercost;
    }

    /**
     * 其它费用
     */
    public void setOthercost(java.math.BigDecimal othercost) {
        this.othercost = othercost;
    }
    /**
     * 当期
     */
    public java.math.BigDecimal getCurrent() {
        return current;
    }

    /**
     * 当期
     */
    public void setCurrent(java.math.BigDecimal current) {
        this.current = current;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulative() {
        return cumulative;
    }

    /**
     * 累计
     */
    public void setCumulative(java.math.BigDecimal cumulative) {
        this.cumulative = cumulative;
    }
    /**
     * 应对措施
     */
    public java.math.BigDecimal getAnswer() {
        return answer;
    }

    /**
     * 应对措施
     */
    public void setAnswer(java.math.BigDecimal answer) {
        this.answer = answer;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 工资
     */
    public java.math.BigDecimal getSalary() {
        return salary;
    }

    /**
     * 工资
     */
    public void setSalary(java.math.BigDecimal salary) {
        this.salary = salary;
    }

    public String getCollectbranchTime1() {
        return collectbranchTime1;
    }

    public void setCollectbranchTime1(String collectbranchTime1) {
        this.collectbranchTime1 = collectbranchTime1;
    }
}

==> ejc-businessplan-impl-3.0.0-20230314.074103-119-sources.jar: com/ejianc/business/busniessplan/bean/FundsplanningdetailEntity.java <==
package com.ejianc.business.busniessplan.bean;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目资金管理策划子表
 *
 * @author generator
 *
 */
 @TableName("ejc_businessplan_fundsplanningdetail")
public class FundsplanningdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="collectbranch_time")
    private java.util.Date collectbranchTime; // 收支时间(日期)
    @TableField(value="collectbranch_time1")
    private java.lang.String collectbranchTime1; // 收支时间(文本)
    @TableField(value="imagenode")
    private java.lang.String imagenode; // 形象进度节点情况
    @TableField(value="plancomplete")
    private java.math.BigDecimal plancomplete; // 计划完成产值
    @TableField(value="civilengineering")
    private java.math.BigDecimal civilengineering; // 土建
    @TableField(value="installation")
    private java.math.BigDecimal installation; // 安装
    @TableField(value="other")
    private java.math.BigDecimal other; // 其它
    @TableField(value="labourservices")
    private java.math.BigDecimal labourservices; // 劳务
    @TableField(value="material")
    private java.math.BigDecimal material; // 材料
    @TableField(value="professional")
    private java.math.BigDecimal professional; // 专业分包
    @TableField(value="othercost")
    private java.math.BigDecimal othercost; // 其它费用
    @TableField(value="current")
    private java.math.BigDecimal current; // 当期
    @TableField(value="cumulative")
    private java.math.BigDecimal cumulative; // 累计
    @TableField(value="answer")
    private java.math.BigDecimal answer; // 应对措施
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="salary")
    private java.math.BigDecimal salary; // 工资
    @TableField(value="cio_amount")
    private java.math.BigDecimal cioAmount;//合计

    @TableField(value="past_flag")
    private java.lang.Integer pastFlag;//是否为往期数据：1是，0否

    public BigDecimal getCioAmount() {
        return cioAmount;
    }

    public void setCioAmount(BigDecimal cioAmount) {
        this.cioAmount = cioAmount;
    }



    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 收支时间(日期)
     */
    public java.util.Date getCollectbranchTime() {
        return collectbranchTime;
    }

    /**
     * 收支时间(日期)
     */
    public void setCollectbranchTime(java.util.Date collectbranchTime) {
        this.collectbranchTime = collectbranchTime;
    }
    /**
     * 形象进度节点情况
     */
    public java.lang.String getImagenode() {
        return imagenode;
    }

    /**
     * 形象进度节点情况
     */
    public void setImagenode(java.lang.String imagenode) {
        this.imagenode = imagenode;
    }
    /**
     * 计划完成产值
     */
    public java.math.BigDecimal getPlancomplete() {
        return plancomplete;
    }

    /**
     * 计划完成产值
     */
    public void setPlancomplete(java.math.BigDecimal plancomplete) {
        this.plancomplete = plancomplete;
    }
    /**
     * 土建
     */
    public java.math.BigDecimal getCivilengineering() {
        return civilengineering;
    }

    /**
     * 土建
     */
    public void setCivilengineering(java.math.BigDecimal civilengineering) {
        this.civilengineering = civilengineering;
    }
    /**
     * 安装
     */
    public java.math.BigDecimal getInstallation() {
        return installation;
    }

    /**
     * 安装
     */
    public void setInstallation(java.math.BigDecimal installation) {
        this.installation = installation;
    }
    /**
     * 其它
     */
    public java.math.BigDecimal getOther() {
        return other;
    }

    /**
     * 其它
     */
    public void setOther(java.math.BigDecimal other) {
        this.other = other;
    }
    /**
     * 劳务
     */
    public java.math.BigDecimal getLabourservices() {
        return labourservices;
    }

    /**
     * 劳务
     */
    public void setLabourservices(java.math.BigDecimal labourservices) {
        this.labourservices = labourservices;
    }
    /**
     * 材料
     */
    public java.math.BigDecimal getMaterial() {
        return material;
    }

    /**
     * 材料
     */
    public void setMaterial(java.math.BigDecimal material) {
        this.material = material;
    }
    /**
     * 专业分包
     */
    public java.math.BigDecimal getProfessional() {
        return professional;
    }

    /**
     * 专业分包
     */
    public void setProfessional(java.math.BigDecimal professional) {
        this.professional = professional;
    }
    /**
     * 其它费用
     */
    public java.math.BigDecimal getOthercost() {
        return othercost;
    }

    /**
     * 其它费用
     */
    public void setOthercost(java.math.BigDecimal othercost) {
        this.othercost = othercost;
    }
    /**
     * 当期
     */
    public java.math.BigDecimal getCurrent() {
        return current;
    }

    /**
     * 当期
     */
    public void setCurrent(java.math.BigDecimal current) {
        this.current = current;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulative() {
        return cumulative;
    }

    /**
     * 累计
     */
    public void setCumulative(java.math.BigDecimal cumulative) {
        this.cumulative = cumulative;
    }
    /**
     * 应对措施
     */
    public java.math.BigDecimal getAnswer() {
        return answer;
    }

    /**
     * 应对措施
     */
    public void setAnswer(java.math.BigDecimal answer) {
        this.answer = answer;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 工资
     */
    public java.math.BigDecimal getSalary() {
        return salary;
    }

    /**
     * 工资
     */
    public void setSalary(java.math.BigDecimal salary) {
        this.salary = salary;
    }

    public String getCollectbranchTime1() {
        return collectbranchTime1;
    }

    public void setCollectbranchTime1(String collectbranchTime1) {
        this.collectbranchTime1 = collectbranchTime1;
    }

    public Integer getPastFlag() {
        return pastFlag;
    }

    public void setPastFlag(Integer pastFlag) {
        this.pastFlag = pastFlag;
    }
}
